### How to contribute

The following is a short step-by-step rundown of what one typically would do to contribute.

* [fork this project](https://github.com/gitpython-developers/GitPython/fork) on GitHub.
* For setting up the environment to run the self tests, please look at `.travis.yml`.
* Please try to **write a test that fails unless the contribution is present.**
* Feel free to add yourself to AUTHORS file. 
* Create a pull request.

